from time import sleep

from .Motor import PicoGo
from .LCD import LCD
from .IRSensor import IRSensor

if __name__ == '__main__' :
    
    robot = PicoGo()
    lcd = LCD()
    irSensor = IRSensor()
    
    lcd.disp_init()

    speed = 20
    duration = 0.02
    
    idx = 0 
    while True:
        idx += 1
        blocks = [ left_block, right_block ] = irSensor.read_blocks()
        
        lcd.disp_ir_sensor( blocks )
        lcd.show() 
        
        print( f"[{idx:4d}] InfraRed left: {left_block}, right: {right_block}" )

        if  left_block and right_block : # 양쪽에 장애물이 있을 때, 좌회전
            robot.left( speed )
            sleep( 5*duration )
        elif left_block : # 좌측 장애물시, 우회전
            robot.right( speed )
            sleep( 5*duration )
        elif right_block :  # 우측 장애물시, 좌회전
            robot.left( speed )
            sleep( 5*duration )
        else :  # 장매물이 없으면, 전진
            robot.forward( speed )
            sleep( duration )
        pass            
        
    pass

pass


#!/usr/bin/env python3
import sys

from PIL import Image
from .LCD import LCD

print("""
image.py - Display an image on the LCD.

If you're using Breakout Garden, plug the 1.3" LCD (SPI)
breakout into the front slot.

""")

if len(sys.argv) < 2:
    print("""Usage: {} <image_file> <display_type>

Where <display_type> is one of:
  * square - 240x240 1.3" Square LCD
  * round  - 240x240 1.3" Round LCD (applies an offset)
  * rect   - 240x135 1.14" Rectangular LCD (applies an offset)
  * dhmini - 320x240 2.0" Display HAT Mini 
""".format(sys.argv[0]))
    sys.exit(1)

image_file = sys.argv[1]

try:
    display_type = sys.argv[2]
except IndexError:
    display_type = "square"

# Create ST7789 LCD display class.

if display_type in ("square", "rect", "round"):
    disp = ST7789.ST7789(
        height=135 if display_type == "rect" else 240,
        rotation=0 if display_type == "rect" else 90,
        port=0,
        cs=ST7789.BG_SPI_CS_FRONT,  # BG_SPI_CS_BACK or BG_SPI_CS_FRONT
        dc=9,
        backlight=19,               # 18 for back BG slot, 19 for front BG slot.
        spi_speed_hz=80 * 1000 * 1000,
        offset_left=0 if display_type == "square" else 40,
        offset_top=53 if display_type == "rect" else 0
    )

elif display_type == "dhmini":
    disp = ST7789.ST7789(
        height=240,
        width=320,
        rotation=180,
        port=0,
        cs=1,
        dc=9,
        backlight=13,
        spi_speed_hz=60 * 1000 * 1000,
        offset_left=0,
        offset_top=0
   )

else:
    print ("Invalid display type!")

WIDTH = disp.width
HEIGHT = disp.height

# Initialize display.
disp.begin()

# Load an image.
print('Loading image: {}...'.format(image_file))
image = Image.open(image_file)

# Resize the image
image = image.resize((WIDTH, HEIGHT))

# Draw the image on the display hardware.
print('Drawing image')

disp.display(image)



__name__ = "picogo"
__package__ = "picogo"
__version__ = '0.0.6'
__author__ = "SkySLAM Co., Ltd."

from .Robot import (
    Robot , 
)

def main_file_copy() :
    print( "main_file_copy" )

    file_exist = True
    file_name = "/main.py"
    
    try:
        f = open( file_name, "r" )
        f.close()
        # continue with the file.
    except OSError:  # open failed
        # handle the file open case
        file_exist = False
    pass
    
    if not file_exist :
        file = open( file_name, "w" )
        file_content = """
if __name__== '__main__' :

print( 'Hello PicoGo!' )
print( 'Running Bluetooth program ... ' )

from picogo import BlueTooth

BlueTooth.main()

print( 'Good bye!' )    
pass
        """
        file.write( file_content )
        file.close()
        
        print( "Done. main_file_copy" )
    pass
pass

main_file_copy() 

print( "picogo __init__.py executed." ) 


from time import sleep, sleep_ms

from .Motor import PicoGo
from .TRSensor import TRSensor
from .LCD import LCD

if __name__ == '__main__':

    print( "TRSensor Test ... \n" )
    
    lcd = LCD()
    lcd.disp_init(flush=1)
    
    trs = TRSensor()
    
    print( "center position = ", trs.center_position() )
    
    if True :
        sleep(3) 
        
        robot = PicoGo()
        
        for i in range(100):
            if  25 < i <= 75:
                robot.setMotor( 30, -30, False )
            else:
                robot.setMotor(-30, 30, False )
            pass
        
            trs.calibrate()
        pass

        robot.stop()

        print( "calibratedMin = ", trs.calibratedMin )
        print( "calibratedMax = ", trs.calibratedMax )
        print( "calibrate done! \n" ) 
    else :
        trs.calibrate()
    pass
    
    idx = 0 
    while True:
        idx += 1
        position, sensors = trs.readLine()
        
        lcd.disp_tr_sensor( position, sensors, flush=1 ) 
        
        print( f"[{idx:4d}] position = {position:+.2f}, sensors = {sensors}" )            
        
    
        sleep( 1 )
    pass

pass 